exec

package
v0.0.3 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Mar 17, 2026 License: MIT Imports: 8 Imported by: 0

Documentation

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

This section is empty.

Types

type Runner

type Runner interface {
	Runtime(ctx context.Context, args ...string) error
	RuntimeOutput(ctx context.Context, args ...string) ([]byte, error)
	// RuntimePipe starts a runtime command and returns its stdout as a reader.
	// The caller must call the returned cleanup function when done.
	RuntimePipe(ctx context.Context, args ...string) (io.ReadCloser, func() error, error)
}

Runner abstracts container runtime command execution.

func New

func New(cfg config.Config) Runner

New creates a Runner from the given config.

Jump to