Documentation
¶
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
This section is empty.
Types ¶
type Runner ¶
type Runner interface {
Runtime(ctx context.Context, args ...string) error
RuntimeOutput(ctx context.Context, args ...string) ([]byte, error)
// RuntimePipe starts a runtime command and returns its stdout as a reader.
// The caller must call the returned cleanup function when done.
RuntimePipe(ctx context.Context, args ...string) (io.ReadCloser, func() error, error)
}
Runner abstracts container runtime command execution.
Click to show internal directories.
Click to hide internal directories.